"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEvent = void 0;
var react_1 = require("react");
var local_cache_1 = require("../util/local-cache");
var uuid_1 = require("primeobjects-helper-util/build/cjs/uuid");
var constants_1 = require("primeobjects-helper-util/build/cjs/constants");
var core_1 = require("primeobjects-helper-util/build/cjs/core");
var SOURCE = 'PO-USE-EVENT';
var useEvent = function (key, senderName) {
    var data = (0, local_cache_1.getLocalCache)(key, {});
    var _a = (0, react_1.useState)(''), valueRefreshed = _a[0], setValuedRefreshed = _a[1];
    var isSSR = constants_1.SSR;
    (0, core_1.doNothing)(valueRefreshed);
    var messageHandler = function (message) {
        var data = message.data;
        if (data.source == SOURCE) {
            setValuedRefreshed((0, uuid_1.newGuid)());
        }
    };
    var sendEvent = function (key, value, expireMinutes) {
        if (constants_1.SSR)
            return console.error('Require window object.');
        (0, local_cache_1.setLocalCache)(key, { value: value, senderName: senderName, id: (0, uuid_1.newGuid)() }, expireMinutes);
        constants_1._window.postMessage({ source: SOURCE, key: key });
    };
    (0, react_1.useEffect)(function () {
        if (isSSR) {
            console.error('Require window object.');
        }
        else {
            if (constants_1._window.addEventListener) {
                constants_1._window.addEventListener("message", messageHandler);
            }
            else {
                constants_1._window.attachEvent("onmessage", messageHandler);
            }
        }
        return function () {
            if (constants_1._window.removeEventListener)
                constants_1._window.removeEventListener("message", messageHandler);
            if (constants_1._window.detachEvent)
                constants_1._window.detachEvent("onmessage", messageHandler);
        };
    }, [isSSR]);
    return [data === null || data === void 0 ? void 0 : data.value, sendEvent, data === null || data === void 0 ? void 0 : data.senderName];
};
exports.useEvent = useEvent;
