"use strict";
//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
// 
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeLocalCache = exports.setLocalCache = exports.getLocalCache = void 0;
var constants_1 = require("primeobjects-helper-util/build/cjs/constants");
var core_1 = require("primeobjects-helper-util/build/cjs/core");
var lodash_1 = require("lodash");
var getLocalCache = function (key, defaultValue) {
    if (!(0, core_1.isNonEmptyString)(key))
        return null;
    if (!(0, core_1.isObject)(constants_1._window.localCache))
        constants_1._window.localCache = {};
    var data = null;
    var cacheData = constants_1._window.localCache[key];
    if ((0, lodash_1.isNil)(cacheData))
        return defaultValue;
    if ((0, core_1.isNonEmptyString)(cacheData)) {
        try {
            data = JSON.parse(cacheData);
            if ((0, core_1.isObject)(data) && (0, lodash_1.isInteger)(data.ttl)) //ttl in seconds
             {
                if (Date.now() > data.ttl * 1000) {
                    (0, exports.removeLocalCache)(key);
                    return !(0, lodash_1.isNil)(defaultValue) ? defaultValue : null;
                }
                else {
                    return data.data;
                }
            }
        }
        catch (_a) {
            data = cacheData;
        }
    }
    else {
        data = cacheData;
    }
    return !(0, lodash_1.isNil)(data) ? data : (!(0, lodash_1.isNil)(defaultValue) ? defaultValue : null);
};
exports.getLocalCache = getLocalCache;
var setLocalCache = function (key, data, expireMinutes) {
    if (!(0, core_1.isNonEmptyString)(key))
        return null;
    if (!(0, core_1.isObject)(constants_1._window.localCache))
        constants_1._window.localCache = {};
    if ((0, lodash_1.isNil)(data))
        return (0, exports.removeLocalCache)(key);
    if (!(0, lodash_1.isNil)(expireMinutes) && (0, lodash_1.isInteger)(expireMinutes) && expireMinutes > 0) {
        var cacheData = { data: data, ttl: (0, core_1.ttl)(expireMinutes) };
        constants_1._window.localCache[key] = JSON.stringify(cacheData);
    }
    else {
        constants_1._window.localCache[key] = (0, core_1.isObject)(data) ? JSON.stringify(data) : data;
    }
};
exports.setLocalCache = setLocalCache;
var removeLocalCache = function (key) {
    if (!(0, core_1.isObject)(constants_1._window.localCache))
        constants_1._window.localCache = {};
    delete constants_1._window.localCache[key];
};
exports.removeLocalCache = removeLocalCache;
