//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
// 
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
import { _window } from 'primeobjects-helper-util/build/cjs/constants';
import { isNonEmptyString, isObject, ttl } from 'primeobjects-helper-util/build/cjs/core';
import { isNil, isInteger } from 'lodash';
export var getLocalCache = function (key, defaultValue) {
    if (!isNonEmptyString(key))
        return null;
    if (!isObject(_window.localCache))
        _window.localCache = {};
    var data = null;
    var cacheData = _window.localCache[key];
    if (isNil(cacheData))
        return defaultValue;
    if (isNonEmptyString(cacheData)) {
        try {
            data = JSON.parse(cacheData);
            if (isObject(data) && isInteger(data.ttl)) //ttl in seconds
             {
                if (Date.now() > data.ttl * 1000) {
                    removeLocalCache(key);
                    return !isNil(defaultValue) ? defaultValue : null;
                }
                else {
                    return data.data;
                }
            }
        }
        catch (_a) {
            data = cacheData;
        }
    }
    else {
        data = cacheData;
    }
    return !isNil(data) ? data : (!isNil(defaultValue) ? defaultValue : null);
};
export var setLocalCache = function (key, data, expireMinutes) {
    if (!isNonEmptyString(key))
        return null;
    if (!isObject(_window.localCache))
        _window.localCache = {};
    if (isNil(data))
        return removeLocalCache(key);
    if (!isNil(expireMinutes) && isInteger(expireMinutes) && expireMinutes > 0) {
        var cacheData = { data: data, ttl: ttl(expireMinutes) };
        _window.localCache[key] = JSON.stringify(cacheData);
    }
    else {
        _window.localCache[key] = isObject(data) ? JSON.stringify(data) : data;
    }
};
export var removeLocalCache = function (key) {
    if (!isObject(_window.localCache))
        _window.localCache = {};
    delete _window.localCache[key];
};
